@@ -1,6 +1,6 @@
 /*
   Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
-  Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -27,12 +27,10 @@
 #include <QPushButton>
 using namespace KAddressBookImportExport;
 
-KAddressBookContactSelectionDialog::KAddressBookContactSelectionDialog(QItemSelectionModel *selectionModel, bool allowToSelectTypeToExport,
-        QWidget *parent)
-    : QDialog(parent),
-      mVCardExport(nullptr)
+KAddressBookContactSelectionDialog::KAddressBookContactSelectionDialog(QItemSelectionModel *selectionModel, bool allowToSelectTypeToExport, QWidget *parent)
+    : QDialog(parent)
+    , mVCardExport(nullptr)
 {
-
     setWindowTitle(i18n("Select Contacts"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
@@ -87,4 +85,3 @@ void KAddressBookContactSelectionDialog::setAddGroupContact(bool addGroupContact
 {
     mSelectionWidget->setAddGroupContact(addGroupContact);
 }
-
