@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -24,18 +24,10 @@
 using namespace SendLater;
 
 SendLaterInfo::SendLaterInfo()
-    : mId(-1)
-    , mRecurrenceEachValue(1)
-    , mRecurrenceUnit(Days)
-    , mRecurrence(false)
 {
 }
 
 SendLaterInfo::SendLaterInfo(const KConfigGroup &config)
-    : mId(-1)
-    , mRecurrenceEachValue(1)
-    , mRecurrenceUnit(Days)
-    , mRecurrence(false)
 {
     readConfig(config);
 }
@@ -161,7 +153,7 @@ void SendLaterInfo::readConfig(const KConfigGroup &config)
     mDateTime = config.readEntry("date", QDateTime::currentDateTime());
     mRecurrence = config.readEntry("recurrence", false);
     mRecurrenceEachValue = config.readEntry("recurrenceValue", 1);
-    mRecurrenceUnit = static_cast<RecurrenceUnit>(config.readEntry("recurrenceUnit", (int)Days));
+    mRecurrenceUnit = static_cast<RecurrenceUnit>(config.readEntry("recurrenceUnit", static_cast<int>(Days)));
     mId = config.readEntry("itemId", -1);
     mSubject = config.readEntry("subject");
     mTo = config.readEntry("to");
@@ -175,7 +167,7 @@ void SendLaterInfo::writeConfig(KConfigGroup &config)
     config.writeEntry("date", mDateTime);
     config.writeEntry("recurrence", mRecurrence);
     config.writeEntry("recurrenceValue", mRecurrenceEachValue);
-    config.writeEntry("recurrenceUnit", (int)mRecurrenceUnit);
+    config.writeEntry("recurrenceUnit", static_cast<int>(mRecurrenceUnit));
     config.writeEntry("itemId", mId);
     config.writeEntry("subject", mSubject);
     config.writeEntry("to", mTo);
