@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -42,8 +42,8 @@ Q_SIGNALS:
     void dateChanged(const QString &);
 private:
     void slotDateTimeChanged();
-    KTimeComboBox *mTimeComboBox;
-    KDateComboBox *mDateComboBox;
+    KTimeComboBox *mTimeComboBox = nullptr;
+    KDateComboBox *mDateComboBox = nullptr;
 };
 }
 
